@@ -1,20 +1,11 @@
-import re
-
 from django.core.urlresolvers import RegexURLResolver
 
 class CMSURLResolver(RegexURLResolver):
     def __init__(self, regex, url_patterns, default_kwargs=None, app_name=None, namespace=None):
         # regex is a string representing a regular expression.
         # urlconf_name is a string representing the module containing URLconfs.
-        self.regex = re.compile(regex, re.UNICODE)
+        super(CMSURLResolver, self).__init__(regex, urlconf_name=None, default_kwargs=default_kwargs, app_name=app_name, namespace=namespace)
         self._url_patterns = url_patterns
-        self.callback = None
-        self.default_kwargs = default_kwargs or {}
-        self.namespace = namespace
-        self.app_name = app_name
-        self._reverse_dict = None
-        self._namespace_dict = None
-        self._app_dict = None
     
     def _get_url_patterns(self):
         return self._url_patterns
