@@ -3,7 +3,7 @@ from django import template
 register = template.Library()
 
 from classytags.core import Options
-from classytags.helpers import InclusionTag
+from classytags.helpers import InclusionTag, Tag
 from classytags.arguments import Argument
 
 class ViewScope(InclusionTag):
@@ -17,3 +17,14 @@ class ViewScope(InclusionTag):
         return {'scopes': context.get('scopes', [])}
 
 register.tag(ViewScope)
+
+class RenderScopeDisplay(Tag):
+    name = 'renderscopedisplay'
+    options = Options(
+        Argument('scopedisplay', resolve=True),
+    )
+    
+    def render_tag(self, context, scopedisplay):
+        return scopedisplay.render(context)
+
+register.tag(RenderScopeDisplay)
