@@ -1,8 +1,8 @@
 from dockit.forms import DocumentForm
 from django import forms
 
-from models import BaseTemplateWidget
-from builtins import CTAWidget
+from dockitcms.widgetblock.models import BaseTemplateWidget
+from dockitcms.widgetblock.builtins import CTAWidget
 
 class BaseTemplateWidgetForm(DocumentForm):
     class Meta:
