@@ -2,7 +2,7 @@ from django.db.models import Model
 from django.contrib.contenttypes.models import ContentType
 from django.core.urlresolvers import reverse
 
-from models import ModelWidgets
+from dockitcms.widgetblock.models import ModelWidgets
 
 def widgets(scope):
     if 'object' in scope.kwargs:
@@ -13,7 +13,7 @@ def widgets(scope):
                 urls = obj.get_manage_urls()
                 if 'edit' in urls:
                     base_url = urls['edit']
-                    manage_urls['list'] = base_url + '?_dotpath=widgets'
+                    manage_urls['list'] = base_url + 'dotpath/widgets/'
             scope.add_data('widgets', obj.widgets, manage_urls)
 
 def modelwidgets(scope):
@@ -28,10 +28,10 @@ def modelwidgets(scope):
             for entry in entries:
                 widgets.extend(entry.widgets)
             #TODO compute admin url
-            url = reverse('admin:widgetblock_modelwidgets_lookup',
-                          kwargs={'app_label':ct.app_label,
-                                  'module_name':ct.model,
-                                  'pk':pk,})
-            manage_urls = {'list':url}
+            #url = reverse('admin:widgetblock_modelwidgets_lookup',
+            #              kwargs={'app_label':ct.app_label,
+            #                      'module_name':ct.model,
+            #                      'pk':pk,})
+            manage_urls = {}#'list':url}
             scope.add_data('widgets', widgets, manage_urls)
 
